@@ -506,3 +506,20 @@ class ImportCellParser:
         if cellobject.value is None:
             return None
         return self._parseyesno(cellobject)
+
+    def IQF023LANGUAGE(self, cellobject: openpyxl.cell.cell.Cell) -> Union[str, None]:
+        """
+        Parse language, one of suported languages
+
+        :param cellobject: openpyxl cell object to parse
+        :return: trimmed & lowercased language
+        """
+        if not isinstance(cellobject, Cell):
+            raise TypeError(f"Provided cell object type {type(cellobject)}, type openpyxl.cell.cell.Cell required")
+        if cellobject.value is None:
+            return None
+        _value_stripped_lower = str(cellobject.value).strip().lower()
+        if _value_stripped_lower not in ["ru", "en", "de"]:
+            raise ImportCellParserException((f"IQF023LANGUAGE: Language not supported by "
+                                             f"parser: {_value_stripped_lower}"))
+        return _value_stripped_lower
